import { Canvas, Chart, Interval, Axis, Legend, Line, Tooltip } from "@antv/f2";
import _ from 'lodash';

export function advertisementSpendInit(ele, devicePixelRatio) {
    const data = [
        {
            time: '周一',
            tem: 6.9,
            city: 'tokyo',
        },
        {
            time: '周二',
            tem: 9.5,
            city: 'tokyo',
        },
        {
            time: '周三',
            tem: 14.5,
            city: 'tokyo',
        },
        {
            time: '周四',
            tem: 18.2,
            city: 'tokyo',
        },
        {
            time: '周五',
            tem: 21.5,
            city: 'tokyo',
        },
        {
            time: '周六',
            tem: 25.2,
            city: 'tokyo',
        },
        {
            time: '周日',
            tem: 26.5,
            city: 'tokyo',
        },
        {
            time: '周一',
            tem: -10.8,
            city: 'newYork',
        },
        {
            time: '周二',
            tem: -5.7,
            city: 'newYork',
        },
        {
            time: '周三',
            tem: -11.3,
            city: 'newYork',
        },
        {
            time: '周四',
            tem: -17,
            city: 'newYork',
        },
        {
            time: '周五',
            tem: -22,
            city: 'newYork',
        },
        {
            time: '周六',
            tem: -24.8,
            city: 'newYork',
        },
        {
            time: '周日',
            tem: -24.1,
            city: 'newYork',
        },
        {
            time: '周一',
            tem: 2.6,
            city: 'berlin',
        },
        {
            time: '周二',
            tem: 3.5,
            city: 'berlin',
        },
        {
            time: '周三',
            tem: 8.4,
            city: 'berlin',
        },
        {
            time: '周四',
            tem: 13.5,
            city: 'berlin',
        },
        {
            time: '周五',
            tem: 17,
            city: 'berlin',
        },
        {
            time: '周六',
            tem: -18.6,
            city: 'berlin',
        },
        {
            time: '周日',
            tem: 17.9,
            city: 'berlin',
        },
    ];
    // 获取 canvas context
    const context = ele.getContext("2d");
    const { props } = (
        <Canvas context={context} pixelRatio={devicePixelRatio}>
            <Chart
                data={data}
                scale={{
                    tem: {
                        tickCount: 5,
                    },
                }}
            >
                <Axis field="time" />
                <Axis field="tem" />
                <Interval
                    x="time"
                    y="tem"
                    color="city"
                    adjust="dodge"
                    style={{
                        field: 'tem',
                        radius: (val) => {
                            return val > 0 ? [4, 4, 0, 0] : [0, 0, 4, 4];
                        },
                    }}
                />
                <Tooltip />
            </Chart>
        </Canvas>
    );
    const canvas = new Canvas(props);
    canvas.render();
}

export function advertisementRingRatioInit(ele, devicePixelRatio) {
    const context = ele.getContext('2d');
    const data = [
        {
            "date": "2010-01-10",
            "type": "能源",
            "value": 99.9
        },
        {
            "date": "2010-01-10",
            "type": "金属",
            "value": 96.6
        },
        {
            "date": "2010-02-10",
            "type": "能源",
            "value": 96.7
        },
        {
            "date": "2010-02-10",
            "type": "金属",
            "value": 91.1
        },
        {
            "date": "2010-03-10",
            "type": "能源",
            "value": 100.2
        },
        {
            "date": "2010-03-10",
            "type": "金属",
            "value": 99.4
        },
        {
            "date": "2010-04-10",
            "type": "能源",
            "value": 104.7
        },
        {
            "date": "2010-04-10",
            "type": "金属",
            "value": 108.1
        },
        {
            "date": "2010-05-10",
            "type": "能源",
            "value": 95.6
        },
        {
            "date": "2010-05-10",
            "type": "金属",
            "value": 96
        },
        {
            "date": "2010-06-10",
            "type": "能源",
            "value": 95.6
        },
        {
            "date": "2010-06-10",
            "type": "金属",
            "value": 89.1
        },
        {
            "date": "2010-07-10",
            "type": "能源",
            "value": 95.3
        },
        {
            "date": "2010-07-10",
            "type": "金属",
            "value": 89.2
        },
        {
            "date": "2010-08-10",
            "type": "能源",
            "value": 96.1
        },
        {
            "date": "2010-08-10",
            "type": "金属",
            "value": 97.6
        },
        {
            "date": "2010-09-10",
            "type": "能源",
            "value": 96.1
        },
        {
            "date": "2010-09-10",
            "type": "金属",
            "value": 100.6
        },
        {
            "date": "2010-10-10",
            "type": "能源",
            "value": 101.6
        },
        {
            "date": "2010-10-10",
            "type": "金属",
            "value": 108.3
        },
        {
            "date": "2010-11-10",
            "type": "能源",
            "value": 105.6
        },
        {
            "date": "2010-11-10",
            "type": "金属",
            "value": 109.4
        },
        {
            "date": "2010-12-10",
            "type": "能源",
            "value": 112.7
        },
        {
            "date": "2010-12-10",
            "type": "金属",
            "value": 114.5
        },
        {
            "date": "2011-01-11",
            "type": "能源",
            "value": 117
        },
        {
            "date": "2011-01-11",
            "type": "金属",
            "value": 120.8
        },
        {
            "date": "2011-02-11",
            "type": "能源",
            "value": 121.8
        },
        {
            "date": "2011-02-11",
            "type": "金属",
            "value": 125.8
        },
        {
            "date": "2011-03-11",
            "type": "能源",
            "value": 133.1
        },
        {
            "date": "2011-03-11",
            "type": "金属",
            "value": 121.4
        },
        {
            "date": "2011-04-11",
            "type": "能源",
            "value": 141.9
        },
        {
            "date": "2011-04-11",
            "type": "金属",
            "value": 124.3
        },
        {
            "date": "2011-05-11",
            "type": "能源",
            "value": 133.1
        },
        {
            "date": "2011-05-11",
            "type": "金属",
            "value": 118.5
        },
        {
            "date": "2011-06-11",
            "type": "能源",
            "value": 131.2
        },
        {
            "date": "2011-06-11",
            "type": "金属",
            "value": 117
        },
        {
            "date": "2011-07-11",
            "type": "能源",
            "value": 133.7
        },
        {
            "date": "2011-07-11",
            "type": "金属",
            "value": 121
        },
        {
            "date": "2011-08-11",
            "type": "能源",
            "value": 125.2
        },
        {
            "date": "2011-08-11",
            "type": "金属",
            "value": 114.8
        },
        {
            "date": "2011-09-11",
            "type": "能源",
            "value": 125.5
        },
        {
            "date": "2011-09-11",
            "type": "金属",
            "value": 109.1
        },
        {
            "date": "2011-10-11",
            "type": "能源",
            "value": 124.2
        },
        {
            "date": "2011-10-11",
            "type": "金属",
            "value": 98.4
        },
        {
            "date": "2011-11-11",
            "type": "能源",
            "value": 129.4
        },
        {
            "date": "2011-11-11",
            "type": "金属",
            "value": 95.8
        },
        {
            "date": "2011-12-11",
            "type": "能源",
            "value": 128
        },
        {
            "date": "2011-12-11",
            "type": "金属",
            "value": 95.1
        },
        {
            "date": "2012-01-12",
            "type": "能源",
            "value": 130.6
        },
        {
            "date": "2012-01-12",
            "type": "金属",
            "value": 100.5
        },
        {
            "date": "2012-02-12",
            "type": "能源",
            "value": 136.2
        },
        {
            "date": "2012-02-12",
            "type": "金属",
            "value": 104
        },
        {
            "date": "2012-03-12",
            "type": "能源",
            "value": 141.2
        },
        {
            "date": "2012-03-12",
            "type": "金属",
            "value": 103.5
        },
        {
            "date": "2012-04-12",
            "type": "能源",
            "value": 136.1
        },
        {
            "date": "2012-04-12",
            "type": "金属",
            "value": 101
        },
        {
            "date": "2012-05-12",
            "type": "能源",
            "value": 126.3
        },
        {
            "date": "2012-05-12",
            "type": "金属",
            "value": 96.6
        },
        {
            "date": "2012-06-12",
            "type": "能源",
            "value": 111.5
        },
        {
            "date": "2012-06-12",
            "type": "金属",
            "value": 91.6
        },
        {
            "date": "2012-07-12",
            "type": "能源",
            "value": 118.6
        },
        {
            "date": "2012-07-12",
            "type": "金属",
            "value": 91.2
        },
        {
            "date": "2012-08-12",
            "type": "能源",
            "value": 127.7
        },
        {
            "date": "2012-08-12",
            "type": "金属",
            "value": 87.7
        },
        {
            "date": "2012-09-12",
            "type": "能源",
            "value": 128.5
        },
        {
            "date": "2012-09-12",
            "type": "金属",
            "value": 93.6
        },
        {
            "date": "2012-10-12",
            "type": "能源",
            "value": 125.9
        },
        {
            "date": "2012-10-12",
            "type": "金属",
            "value": 94
        },
        {
            "date": "2012-11-12",
            "type": "能源",
            "value": 124.1
        },
        {
            "date": "2012-11-12",
            "type": "金属",
            "value": 92.4
        },
        {
            "date": "2012-12-12",
            "type": "能源",
            "value": 124.2
        },
        {
            "date": "2012-12-12",
            "type": "金属",
            "value": 97.4
        },
        {
            "date": "2013-01-13",
            "type": "能源",
            "value": 128.4
        },
        {
            "date": "2013-01-13",
            "type": "金属",
            "value": 100.3
        },
        {
            "date": "2013-02-13",
            "type": "能源",
            "value": 131.2
        },
        {
            "date": "2013-02-13",
            "type": "金属",
            "value": 101.3
        },
        {
            "date": "2013-03-13",
            "type": "能源",
            "value": 126.2
        },
        {
            "date": "2013-03-13",
            "type": "金属",
            "value": 94.5
        },
        {
            "date": "2013-04-13",
            "type": "能源",
            "value": 123.1
        },
        {
            "date": "2013-04-13",
            "type": "金属",
            "value": 90.7
        },
        {
            "date": "2013-05-13",
            "type": "能源",
            "value": 123.2
        },
        {
            "date": "2013-05-13",
            "type": "金属",
            "value": 88.3
        },
        {
            "date": "2013-06-13",
            "type": "能源",
            "value": 122.9
        },
        {
            "date": "2013-06-13",
            "type": "金属",
            "value": 85.4
        },
        {
            "date": "2013-07-13",
            "type": "能源",
            "value": 128.1
        },
        {
            "date": "2013-07-13",
            "type": "金属",
            "value": 85.7
        },
        {
            "date": "2013-08-13",
            "type": "能源",
            "value": 130.9
        },
        {
            "date": "2013-08-13",
            "type": "金属",
            "value": 89.6
        },
        {
            "date": "2013-09-13",
            "type": "能源",
            "value": 131.6
        },
        {
            "date": "2013-09-13",
            "type": "金属",
            "value": 88.2
        },
        {
            "date": "2013-10-13",
            "type": "能源",
            "value": 128.3
        },
        {
            "date": "2013-10-13",
            "type": "金属",
            "value": 89.1
        },
        {
            "date": "2013-11-13",
            "type": "能源",
            "value": 125.4
        },
        {
            "date": "2013-11-13",
            "type": "金属",
            "value": 87.8
        },
        {
            "date": "2013-12-13",
            "type": "能源",
            "value": 129.5
        },
        {
            "date": "2013-12-13",
            "type": "金属",
            "value": 88.7
        },
        {
            "date": "2014-01-14",
            "type": "能源",
            "value": 126.4
        },
        {
            "date": "2014-01-14",
            "type": "金属",
            "value": 88.1
        },
        {
            "date": "2014-02-14",
            "type": "能源",
            "value": 130.6
        },
        {
            "date": "2014-02-14",
            "type": "金属",
            "value": 86.2
        },
        {
            "date": "2014-03-14",
            "type": "能源",
            "value": 127.9
        },
        {
            "date": "2014-03-14",
            "type": "金属",
            "value": 83
        },
        {
            "date": "2014-04-14",
            "type": "能源",
            "value": 128.4
        },
        {
            "date": "2014-04-14",
            "type": "金属",
            "value": 85.5
        },
        {
            "date": "2014-05-14",
            "type": "能源",
            "value": 129
        },
        {
            "date": "2014-05-14",
            "type": "金属",
            "value": 84.8
        },
        {
            "date": "2014-06-14",
            "type": "能源",
            "value": 131.5
        },
        {
            "date": "2014-06-14",
            "type": "金属",
            "value": 84.4
        },
        {
            "date": "2014-07-14",
            "type": "能源",
            "value": 126.9
        },
        {
            "date": "2014-07-14",
            "type": "金属",
            "value": 88.2
        },
        {
            "date": "2014-08-14",
            "type": "能源",
            "value": 121.2
        },
        {
            "date": "2014-08-14",
            "type": "金属",
            "value": 88
        },
        {
            "date": "2014-09-14",
            "type": "能源",
            "value": 116.6
        },
        {
            "date": "2014-09-14",
            "type": "金属",
            "value": 85.1
        },
        {
            "date": "2014-10-14",
            "type": "能源",
            "value": 106.2
        },
        {
            "date": "2014-10-14",
            "type": "金属",
            "value": 82.6
        },
        {
            "date": "2014-11-14",
            "type": "能源",
            "value": 96.4
        },
        {
            "date": "2014-11-14",
            "type": "金属",
            "value": 82.9
        },
        {
            "date": "2014-12-14",
            "type": "能源",
            "value": 78.6
        },
        {
            "date": "2014-12-14",
            "type": "金属",
            "value": 78.8
        },
        {
            "date": "2015-01-15",
            "type": "能源",
            "value": 63.1
        },
        {
            "date": "2015-01-15",
            "type": "金属",
            "value": 73.9
        },
        {
            "date": "2015-02-15",
            "type": "能源",
            "value": 70.4
        },
        {
            "date": "2015-02-15",
            "type": "金属",
            "value": 72.4
        },
        {
            "date": "2015-03-15",
            "type": "能源",
            "value": 68.1
        },
        {
            "date": "2015-03-15",
            "type": "金属",
            "value": 71.8
        },
        {
            "date": "2015-04-15",
            "type": "能源",
            "value": 72.2
        },
        {
            "date": "2015-04-15",
            "type": "金属",
            "value": 72.1
        },
        {
            "date": "2015-05-15",
            "type": "能源",
            "value": 77.8
        },
        {
            "date": "2015-05-15",
            "type": "金属",
            "value": 74.6
        },
        {
            "date": "2015-06-15",
            "type": "能源",
            "value": 76.3
        },
        {
            "date": "2015-06-15",
            "type": "金属",
            "value": 70.3
        },
        {
            "date": "2015-07-15",
            "type": "能源",
            "value": 68.8
        },
        {
            "date": "2015-07-15",
            "type": "金属",
            "value": 65.7
        },
        {
            "date": "2015-08-15",
            "type": "能源",
            "value": 59.5
        },
        {
            "date": "2015-08-15",
            "type": "金属",
            "value": 62.7
        },
        {
            "date": "2015-09-15",
            "type": "能源",
            "value": 59.7
        },
        {
            "date": "2015-09-15",
            "type": "金属",
            "value": 63.4
        },
        {
            "date": "2015-10-15",
            "type": "能源",
            "value": 59.7
        },
        {
            "date": "2015-10-15",
            "type": "金属",
            "value": 62.2
        },
        {
            "date": "2015-11-15",
            "type": "能源",
            "value": 55.2
        },
        {
            "date": "2015-11-15",
            "type": "金属",
            "value": 57.8
        },
        {
            "date": "2015-12-15",
            "type": "能源",
            "value": 47.8
        },
        {
            "date": "2015-12-15",
            "type": "金属",
            "value": 56.3
        },
        {
            "date": "2016-01-16",
            "type": "能源",
            "value": 40.5
        },
        {
            "date": "2016-01-16",
            "type": "金属",
            "value": 55.2
        },
        {
            "date": "2016-02-16",
            "type": "能源",
            "value": 41.2
        },
        {
            "date": "2016-02-16",
            "type": "金属",
            "value": 57.7
        },
        {
            "date": "2016-03-16",
            "type": "能源",
            "value": 47.3
        },
        {
            "date": "2016-03-16",
            "type": "金属",
            "value": 61.2
        },
        {
            "date": "2016-04-16",
            "type": "能源",
            "value": 51.1
        },
        {
            "date": "2016-04-16",
            "type": "金属",
            "value": 62
        },
        {
            "date": "2016-05-16",
            "type": "能源",
            "value": 56.6
        },
        {
            "date": "2016-05-16",
            "type": "金属",
            "value": 60
        },
        {
            "date": "2016-06-16",
            "type": "能源",
            "value": 59.4
        },
        {
            "date": "2016-06-16",
            "type": "金属",
            "value": 60.3
        },
        {
            "date": "2016-07-16",
            "type": "能源",
            "value": 56.6
        },
        {
            "date": "2016-07-16",
            "type": "金属",
            "value": 63.5
        },
        {
            "date": "2016-08-16",
            "type": "能源",
            "value": 57.6
        },
        {
            "date": "2016-08-16",
            "type": "金属",
            "value": 63.8
        },
        {
            "date": "2016-09-16",
            "type": "能源",
            "value": 58.2
        },
        {
            "date": "2016-09-16",
            "type": "金属",
            "value": 62.8
        },
        {
            "date": "2016-10-16",
            "type": "能源",
            "value": 63.7
        },
        {
            "date": "2016-10-16",
            "type": "金属",
            "value": 64.1
        },
        {
            "date": "2016-11-16",
            "type": "能源",
            "value": 59.4
        },
        {
            "date": "2016-11-16",
            "type": "金属",
            "value": 71.5
        },
        {
            "date": "2016-12-16",
            "type": "能源",
            "value": 68.4
        },
        {
            "date": "2016-12-16",
            "type": "金属",
            "value": 73.5
        },
        {
            "date": "2017-01-17",
            "type": "能源",
            "value": 68.9
        },
        {
            "date": "2017-01-17",
            "type": "金属",
            "value": 74.5
        },
        {
            "date": "2017-02-17",
            "type": "能源",
            "value": 69.4
        },
        {
            "date": "2017-02-17",
            "type": "金属",
            "value": 77.9
        },
        {
            "date": "2017-03-17",
            "type": "能源",
            "value": 65.3
        },
        {
            "date": "2017-03-17",
            "type": "金属",
            "value": 77.3
        },
        {
            "date": "2017-04-17",
            "type": "能源",
            "value": 67.1
        },
        {
            "date": "2017-04-17",
            "type": "金属",
            "value": 74
        },
        {
            "date": "2017-05-17",
            "type": "能源",
            "value": 64.3
        },
        {
            "date": "2017-05-17",
            "type": "金属",
            "value": 72.2
        },
        {
            "date": "2017-06-17",
            "type": "能源",
            "value": 60.4
        },
        {
            "date": "2017-06-17",
            "type": "金属",
            "value": 71.7
        },
        {
            "date": "2017-07-17",
            "type": "能源",
            "value": 62.3
        },
        {
            "date": "2017-07-17",
            "type": "金属",
            "value": 75.4
        },
        {
            "date": "2017-08-17",
            "type": "能源",
            "value": 65
        },
        {
            "date": "2017-08-17",
            "type": "金属",
            "value": 81.6
        },
        {
            "date": "2017-09-17",
            "type": "能源",
            "value": 68.5
        },
        {
            "date": "2017-09-17",
            "type": "金属",
            "value": 82.7
        }
    ];
    const { props } = (
        <Canvas context={context} pixelRatio={devicePixelRatio}>
            <Chart data={data}>
                <Axis
                    field="date"
                    tickCount={3}
                    style={{
                        label: { align: 'between' },
                    }}
                />
                <Axis field="value" tickCount={5} />
                <Line x="date" y="value" lineWidth="4px" color="type" />
                <Legend
                    position="top"
                    style={{
                        justifyContent: 'space-around',
                    }}
                    triggerMap={{
                        press: (items, records, legend) => {
                            const map = {};
                            items.forEach((item) => (map[item.name] = _.clone(item)));
                            records.forEach((record) => {
                                map[record.type].value = record.value;
                            });
                            legend.setItems(_.values(map));
                        },
                        pressend: (items, records, legend) => {
                            legend.setItems(items);
                        },
                    }}
                />
                <Tooltip />
            </Chart>
        </Canvas>
    )
    const chart = new Canvas(props);
    chart.render();
}